@@ -195,7 +195,8 @@ class Node:
         self.get_subject()  
         # if graph does not exist => create graph
         if getattr(self,'graph',None) is None : 
-            self.graph=Graph()                  
+            graph=Graph()              
+            self.graph=ut.bind_ontologies(graph)             
             self.graph.add((self.subject, RDF.type, Literal(str(type(self)))))
   
         # enumerate attributes in node and write them to triples
